@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_GlobalConfig_qtbase_src_corelib_global_qconfig_p_h_H
+#define QT_FEATURES_GlobalConfig_qtbase_src_corelib_global_qconfig_p_h_H
+
 #define QT_FEATURE_use_bfd_linker -1
 
 #define QT_FEATURE_use_gold_linker -1
@@ -144,3 +147,5 @@
 
 #define QT_FEATURE_relro_now_linker -1
 
+
+#endif // QT_FEATURES_GlobalConfig_qtbase_src_corelib_global_qconfig_p_h_H
